***********
Simple Poll
***********

This simple poll has a single question and a pie chart display. Since the pie chart is the default display for a choice type question, we don't have to set up any survey reports.

/admin/crowdsourcing/survey/add/
================================

.. image:: images/SimplePollSurvey.png

/crowdsourcing/my-simple-poll/
==============================

.. image:: images/SimplePollEntry.png

/crowdsourcing/my-simple-poll/report/
=====================================

.. image:: images/SimplePollResults.png
